==> grc-ui-container-v2.2.2-6.tar.gz: package/src/components/Alert/examples/Alert.md <==
---
id: Alert
section: components
cssPrefix: pf-c-alert
propComponents: ['Alert', 'AlertActionCloseButton', 'AlertActionLink']
ouia: true
---

import './alert.css';

## Examples

### Types
```js
import React from 'react';
import { Alert } from '@patternfly/react-core';

class AlertTypes extends React.Component {
  render() {
    return (
      <React.Fragment>
        <Alert title="Default alert title" />
        <Alert variant="info" title="Info alert title" />
        <Alert variant="success" title="Success alert title" />
        <Alert variant="warning" title="Warning alert title" />
        <Alert variant="danger" title="Danger alert title" />
      </React.Fragment>
    );
  }
}
```

### Variations
```js
import React from 'react';
import { Alert, AlertActionCloseButton, AlertActionLink } from '@patternfly/react-core';

class AlertVariations extends React.Component {
  render() {
    return (
      <React.Fragment>
        <Alert
          variant="success"
          title="Success alert title"
          actionClose={<AlertActionCloseButton onClose={() => alert('Clicked the close button')} />}
          actionLinks={
            <React.Fragment>
              <AlertActionLink onClick={() => alert('Clicked on View details')}>View details</AlertActionLink>
              <AlertActionLink onClick={() => alert('Clicked on Ignore')}>Ignore</AlertActionLink>
            </React.Fragment>
          }
        >
          <p>Success alert description. This should tell the user more information about the alert.</p>
        </Alert>
        <Alert variant="success" title="Success alert title" actionClose={<AlertActionCloseButton onClose={() => alert('Clicked the close button')} />}>
          <p>
            Success alert description. This should tell the user more information about the alert.{' '}
            <a href="#">This is a link.</a>
          </p>
        </Alert>
        <Alert
          variant="success"
          title="Success alert title"
          actionClose={<AlertActionCloseButton onClose={() => alert('Clicked the close button')} />}
          actionLinks={
            <React.Fragment>
              <AlertActionLink onClick={() => alert('Clicked on View details')}>View details</AlertActionLink>
              <AlertActionLink onClick={() => alert('Clicked on Ignore')}>Ignore</AlertActionLink>
            </React.Fragment>
          }
        />
        <Alert variant="success" title="Success alert title" actionClose={<AlertActionCloseButton onClose={() => alert('Clicked the close button')} />} />
        <Alert variant="success" title="Success alert title" />
      </React.Fragment>
    );
  }
}
```

### Inline types
```js
import React from 'react';
import { Alert } from '@patternfly/react-core';

class InlineAlert extends React.Component {
  render() {
    return (
      <React.Fragment>
        <Alert variant="default" isInline title="Default inline alert title" />
        <Alert variant="info" isInline title="Info inline alert title" />
        <Alert variant="success" isInline title="Success inline alert title" />
        <Alert variant="warning" isInline title="Warning inline alert title" />
        <Alert variant="danger" isInline title="Danger inline alert title" />
      </React.Fragment>
    );
  }
}
```

### Inline variations
```js
import React from 'react';
import { Alert, AlertActionCloseButton, AlertActionLink } from '@patternfly/react-core';

class InlineAlertVariations extends React.Component {
  render() {
    return (
      <React.Fragment>
        <Alert
          isInline
          variant="success"
          title="Success alert title"
          actionClose={<AlertActionCloseButton onClose={() => alert('Clicked the close button')} />}
          actionLinks={
            <React.Fragment>
              <AlertActionLink onClick={() => alert('Clicked on View details')}>View details</AlertActionLink>
              <AlertActionLink onClick={() => alert('Clicked on Ignore')}>Ignore</AlertActionLink>
            </React.Fragment>
          }
        >
          <p>Success alert description. This should tell the user more information about the alert.</p>
        </Alert>
        <Alert isInline variant="success" title="Success alert title" actionClose={<AlertActionCloseButton onClose={() => alert('Clicked the close button')} />}>
          <p>
            Success alert description. This should tell the user more information about the alert.{' '}
            <a href="#">This is a link.</a>
          </p>
        </Alert>
        <Alert
          isInline
          variant="success"
          title="Success alert title"
          actionClose={<AlertActionCloseButton onClose={() => alert('Clicked the close button')} />}
          actionLinks={
            <React.Fragment>
              <AlertActionLink onClick={() => alert('Clicked on View details')}>View details</AlertActionLink>
              <AlertActionLink onClick={() => alert('Clicked on Ignore')}>Ignore</AlertActionLink>
            </React.Fragment>
          }
        />
        <Alert
          isInline
          variant="success"
          title="Success alert title"
          actionClose={<AlertActionCloseButton onClose={() => alert('Clicked the close button')} />}
        />
        <Alert isInline variant="success" title="Success alert title" />
      </React.Fragment>
    );
  }
}
```

### Static live region alert
```js
import React from 'react';
import { Alert, AlertActionCloseButton } from '@patternfly/react-core';

class StaticLiveRegionAlert extends React.Component {
  render() {
    return (
      <React.Fragment>
        <Alert
          isLiveRegion
          variant="info"
          title="Default live region configuration"
          actionClose={<AlertActionCloseButton onClose={() => alert('Clicked the close button')} />}
        >
          This Alert uses the recommended <code>isLiveRegion</code> prop to automatically sets ARIA attributes and CSS
          classes.
        </Alert>
        <Alert
          aria-live="assertive"
          aria-relevant="additions text"
          aria-atomic="true"
          variant="info"
          title="Customized live region"
          actionClose={<AlertActionCloseButton onClose={() => alert('Clicked the close button')} />}
        >
          You can alternatively omit the <code>isLiveRegion</code> prop to specify ARIA attributes and CSS manually on
          the containing element.
        </Alert>
      </React.Fragment>
    );
  }
}
```

### Dynamic live region alert
```js
import React from 'react';
import { Alert, InputGroup } from '@patternfly/react-core';

class DynamicLiveRegionAlert extends React.Component {
  constructor() {
    super();
    this.state = {
      alerts: []
    };
  }

  render() {
    const addAlert = alertProps => {
      this.setState({ alerts: [...this.state.alerts, alertProps] });
    };
    const getUniqueId = () => new Date().getTime();
    const addSuccessAlert = () => {
      addAlert({
        title: 'Single Success Alert',
        variant: 'success',
        isLiveRegion: true,
        key: getUniqueId()
      });
    };
    const addInfoAlert = () => {
      addAlert({
        title: 'Single Info Alert',
        variant: 'info',
        ariaLive: 'polite',
        ariaRelevant: 'additions text',
        ariaAtomic: 'false',
        key: getUniqueId()
      });
    };
    const addDangerAlert = () => {
      addAlert({
        title: 'Single Danger Alert',
        variant: 'danger',
        ariaLive: 'assertive',
        ariaRelevant: 'additions text',
        ariaAtomic: 'false',
        key: getUniqueId()
      });
    };
    const btnClasses = ['pf-c-button', 'pf-m-secondary'].join(' ');
    return (
      <React.Fragment>
        <InputGroup style={{ marginBottom: '16px' }}>
          <button onClick={addSuccessAlert} type="button" className={btnClasses}>
            Add Single Success Alert
          </button>
          <button onClick={addInfoAlert} type="button" className={btnClasses}>
            Add Single Info Alert
          </button>
          <button onClick={addDangerAlert} type="button" className={btnClasses}>
            Add Single Danger Alert
          </button>
        </InputGroup>
        {this.state.alerts.map(({ title, variant, isLiveRegion, ariaLive, ariaRelevant, ariaAtomic, key }) => (
          <Alert
            variant={variant}
            title={title}
            isLiveRegion={isLiveRegion}
            aria-live={ariaLive}
            aria-relevant={ariaRelevant}
            aria-atomic={ariaAtomic}
            key={key}
          />
        ))}
      </React.Fragment>
    );
  }
}
```

### Async live region alert
```js
import React from 'react';
import { Alert, InputGroup } from '@patternfly/react-core';

class AsyncLiveRegionAlert extends React.Component {
  constructor() {
    super();
    this.state = {
      alerts: [],
      timer: null
    };
    this.stopAsyncAlerts = () => {
      clearInterval(this.state.timer);
    };
  }
  componentWillUnmount() {
    this.stopAsyncAlerts();
  }
  render() {
    const addAlert = incomingAlerts => {
      this.setState({ alerts: [...this.state.alerts, incomingAlerts] });
    };
    const getUniqueId = () => new Date().getTime();
    const startAsyncAlerts = () => {
      let timerValue = setInterval(() => {
        addAlert({
          title: `This is a async alert number ${this.state.alerts.length + 1}`,
          variant: 'info',
          isLiveRegion: true,
          key: getUniqueId()
        });
      }, 1500);
      this.setState({ timer: timerValue });
    };
    const btnClasses = ['pf-c-button', 'pf-m-secondary'].join(' ');
    return (
      <React.Fragment>
        <InputGroup style={{ marginBottom: '16px' }}>
          <button onClick={startAsyncAlerts} type="button" className={btnClasses}>
            Start Async Info Alerts
          </button>
          <button onClick={this.stopAsyncAlerts} type="button" className={btnClasses}>
            Stop Async Info Alerts
          </button>
        </InputGroup>
        {this.state.alerts.map(({ title, variant, isLiveRegion, key }) => (
          <Alert variant={variant} title={title} isLiveRegion={isLiveRegion} key={key} />
        ))}
      </React.Fragment>
    );
  }
}
```

### Alert timeout
```js
import React from 'react';
import { Alert, Button } from '@patternfly/react-core';

class AlertTimeout extends React.Component {
  constructor() {
    super();
    this.state = {
      isOpen: false
    };
    this.onClick = () => {
      this.setState({isOpen:true})
    };
  }

  render() {
    const { isOpen } = this.state;
    const buttonText = !isOpen ? "Show 2 alerts" : "0 alerts to show";
    return (
      <React.Fragment>
        <Button variant="secondary" onClick={this.onClick} isDisabled={isOpen} >{buttonText} </Button>
        {this.state.isOpen &&
        <React.Fragment>
          <Alert title="Default timeout Alert" timeout={true}>This alert will dismiss after 8 seconds </Alert>
          <Alert title="Custom timeout Alert" timeout={16000}>This alert will dismiss after 16 seconds </Alert>
        </React.Fragment>
        }
      </React.Fragment>
    );
  }
}
```

### Truncate
```js
import React from 'react';
import { Alert } from '@patternfly/react-core';
class AlertTypes extends React.Component {
  render() {
    return (
      <React.Fragment>
        <Alert variant="info" truncateTitle={1} title={`
Lorem ipsum dolor sit amet, consectetur adipiscing elit. Curabitur pellentesque neque cursus enim fringilla tincidunt. Proin lobortis aliquam dictum. Nam vel ullamcorper nulla, nec blandit dolor. Vivamus pellentesque neque justo, nec accumsan nulla rhoncus id. Suspendisse mollis, tortor quis faucibus volutpat, sem leo fringilla turpis, ac lacinia augue metus in nulla. Cras vestibulum lacinia orci. Pellentesque sodales consequat interdum. Sed porttitor tincidunt metus nec iaculis. Pellentesque non commodo justo. Morbi feugiat rhoncus neque, vitae facilisis diam aliquam nec. Sed dapibus vitae quam at tristique. Nunc vel commodo mi. Mauris et rhoncus leo.
        `} />
        <Alert variant="warning" truncateTitle={2} title={`
Lorem ipsum dolor sit amet, consectetur adipiscing elit. Curabitur pellentesque neque cursus enim fringilla tincidunt. Proin lobortis aliquam dictum. Nam vel ullamcorper nulla, nec blandit dolor. Vivamus pellentesque neque justo, nec accumsan nulla rhoncus id. Suspendisse mollis, tortor quis faucibus volutpat, sem leo fringilla turpis, ac lacinia augue metus in nulla. Cras vestibulum lacinia orci. Pellentesque sodales consequat interdum. Sed porttitor tincidunt metus nec iaculis. Pellentesque non commodo justo. Morbi feugiat rhoncus neque, vitae facilisis diam aliquam nec. Sed dapibus vitae quam at tristique. Nunc vel commodo mi. Mauris et rhoncus leo.
        `} />
        <Alert variant="danger" truncateTitle={3} title={`
Lorem ipsum dolor sit amet, consectetur adipiscing elit. Curabitur pellentesque neque cursus enim fringilla tincidunt. Proin lobortis aliquam dictum. Nam vel ullamcorper nulla, nec blandit dolor. Vivamus pellentesque neque justo, nec accumsan nulla rhoncus id. Suspendisse mollis, tortor quis faucibus volutpat, sem leo fringilla turpis, ac lacinia augue metus in nulla. Cras vestibulum lacinia orci. Pellentesque sodales consequat interdum. Sed porttitor tincidunt metus nec iaculis. Pellentesque non commodo justo. Morbi feugiat rhoncus neque, vitae facilisis diam aliquam nec. Sed dapibus vitae quam at tristique. Nunc vel commodo mi. Mauris et rhoncus leo.
        `} />
      </React.Fragment>
    );
  }
}
```

==> grc-ui-container-v2.3.4-7.tar.gz: package/src/components/Alert/examples/Alert.md <==
---
id: Alert
section: components
cssPrefix: pf-c-alert
propComponents: ['Alert', 'AlertActionCloseButton', 'AlertActionLink']
ouia: true
---

import './alert.css';
import UsersIcon from '@patternfly/react-icons/dist/js/icons/users-icon';
import BoxIcon from '@patternfly/react-icons/dist/js/icons/box-icon';
import DatabaseIcon from '@patternfly/react-icons/dist/js/icons/database-icon';
import ServerIcon from '@patternfly/react-icons/dist/js/icons/server-icon';
import LaptopIcon from '@patternfly/react-icons/dist/js/icons/laptop-icon';

## Examples

### Types
```js
import React from 'react';
import { Alert } from '@patternfly/react-core';

class AlertTypes extends React.Component {
  render() {
    return (
      <React.Fragment>
        <Alert title="Default alert title" />
        <Alert variant="info" title="Info alert title" />
        <Alert variant="success" title="Success alert title" />
        <Alert variant="warning" title="Warning alert title" />
        <Alert variant="danger" title="Danger alert title" />
      </React.Fragment>
    );
  }
}
```

### Variations
```js
import React from 'react';
import { Alert, AlertActionCloseButton, AlertActionLink } from '@patternfly/react-core';

class AlertVariations extends React.Component {
  render() {
    return (
      <React.Fragment>
        <Alert
          variant="success"
          title="Success alert title"
          actionClose={<AlertActionCloseButton onClose={() => alert('Clicked the close button')} />}
          actionLinks={
            <React.Fragment>
              <AlertActionLink onClick={() => alert('Clicked on View details')}>View details</AlertActionLink>
              <AlertActionLink onClick={() => alert('Clicked on Ignore')}>Ignore</AlertActionLink>
            </React.Fragment>
          }
        >
          <p>Success alert description. This should tell the user more information about the alert.</p>
        </Alert>
        <Alert variant="success" title="Success alert title" actionClose={<AlertActionCloseButton onClose={() => alert('Clicked the close button')} />}>
          <p>
            Success alert description. This should tell the user more information about the alert.{' '}
            <a href="#">This is a link.</a>
          </p>
        </Alert>
        <Alert
          variant="success"
          title="Success alert title"
          actionClose={<AlertActionCloseButton onClose={() => alert('Clicked the close button')} />}
          actionLinks={
            <React.Fragment>
              <AlertActionLink onClick={() => alert('Clicked on View details')}>View details</AlertActionLink>
              <AlertActionLink onClick={() => alert('Clicked on Ignore')}>Ignore</AlertActionLink>
            </React.Fragment>
          }
        />
        <Alert variant="success" title="Success alert title" actionClose={<AlertActionCloseButton onClose={() => alert('Clicked the close button')} />} />
        <Alert variant="success" title="Success alert title" />
      </React.Fragment>
    );
  }
}
```

### Inline types
```js
import React from 'react';
import { Alert } from '@patternfly/react-core';

class InlineAlert extends React.Component {
  render() {
    return (
      <React.Fragment>
        <Alert variant="default" isInline title="Default inline alert title" />
        <Alert variant="info" isInline title="Info inline alert title" />
        <Alert variant="success" isInline title="Success inline alert title" />
        <Alert variant="warning" isInline title="Warning inline alert title" />
        <Alert variant="danger" isInline title="Danger inline alert title" />
      </React.Fragment>
    );
  }
}
```

### Inline variations
```js
import React from 'react';
import { Alert, AlertActionCloseButton, AlertActionLink } from '@patternfly/react-core';

class InlineAlertVariations extends React.Component {
  render() {
    return (
      <React.Fragment>
        <Alert
          isInline
          variant="success"
          title="Success alert title"
          actionClose={<AlertActionCloseButton onClose={() => alert('Clicked the close button')} />}
          actionLinks={
            <React.Fragment>
              <AlertActionLink onClick={() => alert('Clicked on View details')}>View details</AlertActionLink>
              <AlertActionLink onClick={() => alert('Clicked on Ignore')}>Ignore</AlertActionLink>
            </React.Fragment>
          }
        >
          <p>Success alert description. This should tell the user more information about the alert.</p>
        </Alert>
        <Alert isInline variant="success" title="Success alert title" actionClose={<AlertActionCloseButton onClose={() => alert('Clicked the close button')} />}>
          <p>
            Success alert description. This should tell the user more information about the alert.{' '}
            <a href="#">This is a link.</a>
          </p>
        </Alert>
        <Alert
          isInline
          variant="success"
          title="Success alert title"
          actionClose={<AlertActionCloseButton onClose={() => alert('Clicked the close button')} />}
          actionLinks={
            <React.Fragment>
              <AlertActionLink onClick={() => alert('Clicked on View details')}>View details</AlertActionLink>
              <AlertActionLink onClick={() => alert('Clicked on Ignore')}>Ignore</AlertActionLink>
            </React.Fragment>
          }
        />
        <Alert
          isInline
          variant="success"
          title="Success alert title"
          actionClose={<AlertActionCloseButton onClose={() => alert('Clicked the close button')} />}
        />
        <Alert isInline variant="success" title="Success alert title" />
      </React.Fragment>
    );
  }
}
```

### Static live region alert
```js
import React from 'react';
import { Alert, AlertActionCloseButton } from '@patternfly/react-core';

class StaticLiveRegionAlert extends React.Component {
  render() {
    return (
      <React.Fragment>
        <Alert
          isLiveRegion
          variant="info"
          title="Default live region configuration"
          actionClose={<AlertActionCloseButton onClose={() => alert('Clicked the close button')} />}
        >
          This Alert uses the recommended <code>isLiveRegion</code> prop to automatically sets ARIA attributes and CSS
          classes.
        </Alert>
        <Alert
          aria-live="assertive"
          aria-relevant="additions text"
          aria-atomic="true"
          variant="info"
          title="Customized live region"
          actionClose={<AlertActionCloseButton onClose={() => alert('Clicked the close button')} />}
        >
          You can alternatively omit the <code>isLiveRegion</code> prop to specify ARIA attributes and CSS manually on
          the containing element.
        </Alert>
      </React.Fragment>
    );
  }
}
```

### Dynamic live region alert
```js
import React from 'react';
import { Alert, InputGroup } from '@patternfly/react-core';

class DynamicLiveRegionAlert extends React.Component {
  constructor() {
    super();
    this.state = {
      alerts: []
    };
  }

  render() {
    const addAlert = alertProps => {
      this.setState({ alerts: [...this.state.alerts, alertProps] });
    };
    const getUniqueId = () => new Date().getTime();
    const addSuccessAlert = () => {
      addAlert({
        title: 'Single Success Alert',
        variant: 'success',
        isLiveRegion: true,
        key: getUniqueId()
      });
    };
    const addInfoAlert = () => {
      addAlert({
        title: 'Single Info Alert',
        variant: 'info',
        ariaLive: 'polite',
        ariaRelevant: 'additions text',
        ariaAtomic: 'false',
        key: getUniqueId()
      });
    };
    const addDangerAlert = () => {
      addAlert({
        title: 'Single Danger Alert',
        variant: 'danger',
        ariaLive: 'assertive',
        ariaRelevant: 'additions text',
        ariaAtomic: 'false',
        key: getUniqueId()
      });
    };
    const btnClasses = ['pf-c-button', 'pf-m-secondary'].join(' ');
    return (
      <React.Fragment>
        <InputGroup style={{ marginBottom: '16px' }}>
          <button onClick={addSuccessAlert} type="button" className={btnClasses}>
            Add Single Success Alert
          </button>
          <button onClick={addInfoAlert} type="button" className={btnClasses}>
            Add Single Info Alert
          </button>
          <button onClick={addDangerAlert} type="button" className={btnClasses}>
            Add Single Danger Alert
          </button>
        </InputGroup>
        {this.state.alerts.map(({ title, variant, isLiveRegion, ariaLive, ariaRelevant, ariaAtomic, key }) => (
          <Alert
            variant={variant}
            title={title}
            isLiveRegion={isLiveRegion}
            aria-live={ariaLive}
            aria-relevant={ariaRelevant}
            aria-atomic={ariaAtomic}
            key={key}
          />
        ))}
      </React.Fragment>
    );
  }
}
```

### Async live region alert
```js
import React from 'react';
import { Alert, InputGroup } from '@patternfly/react-core';

class AsyncLiveRegionAlert extends React.Component {
  constructor() {
    super();
    this.state = {
      alerts: [],
      timer: null
    };
    this.stopAsyncAlerts = () => {
      clearInterval(this.state.timer);
    };
  }
  componentWillUnmount() {
    this.stopAsyncAlerts();
  }
  render() {
    const addAlert = incomingAlerts => {
      this.setState({ alerts: [...this.state.alerts, incomingAlerts] });
    };
    const getUniqueId = () => new Date().getTime();
    const startAsyncAlerts = () => {
      let timerValue = setInterval(() => {
        addAlert({
          title: `This is a async alert number ${this.state.alerts.length + 1}`,
          variant: 'info',
          isLiveRegion: true,
          key: getUniqueId()
        });
      }, 1500);
      this.setState({ timer: timerValue });
    };
    const btnClasses = ['pf-c-button', 'pf-m-secondary'].join(' ');
    return (
      <React.Fragment>
        <InputGroup style={{ marginBottom: '16px' }}>
          <button onClick={startAsyncAlerts} type="button" className={btnClasses}>
            Start Async Info Alerts
          </button>
          <button onClick={this.stopAsyncAlerts} type="button" className={btnClasses}>
            Stop Async Info Alerts
          </button>
        </InputGroup>
        {this.state.alerts.map(({ title, variant, isLiveRegion, key }) => (
          <Alert variant={variant} title={title} isLiveRegion={isLiveRegion} key={key} />
        ))}
      </React.Fragment>
    );
  }
}
```

### Alert timeout
```js
import React from 'react';
import { Alert, AlertActionLink, Button } from '@patternfly/react-core';

class AlertTimeout extends React.Component {
  constructor() {
    super();
    this.state = {
      alerts: []
    };
    this.onClick = () => {
      const timeout = 8000;
      this.state.alerts.push(
        <Alert title="Default timeout Alert" timeout={timeout} actionLinks={
          <React.Fragment>
            <AlertActionLink>View details</AlertActionLink>
            <AlertActionLink>Ignore</AlertActionLink>
          </React.Fragment>
        }>
          This alert will dismiss after {`${timeout / 1000} seconds`}
        </Alert>
      );
      this.setState({ alerts: [...this.state.alerts] })
    };
  }

  render() {
    return (
      <React.Fragment>
        <Button variant="secondary" onClick={this.onClick}>Add alert</Button>
        <Button variant="secondary" onClick={() => this.setState({ alerts: [] })}>Remove all alerts</Button>
        {this.state.alerts}
      </React.Fragment>
    );
  }
}
```

### Truncate
```js
import React from 'react';
import { Alert } from '@patternfly/react-core';
class AlertTypes extends React.Component {
  render() {
    return (
      <React.Fragment>
        <Alert variant="info" truncateTitle={1} title={`
Lorem ipsum dolor sit amet, consectetur adipiscing elit. Curabitur pellentesque neque cursus enim fringilla tincidunt. Proin lobortis aliquam dictum. Nam vel ullamcorper nulla, nec blandit dolor. Vivamus pellentesque neque justo, nec accumsan nulla rhoncus id. Suspendisse mollis, tortor quis faucibus volutpat, sem leo fringilla turpis, ac lacinia augue metus in nulla. Cras vestibulum lacinia orci. Pellentesque sodales consequat interdum. Sed porttitor tincidunt metus nec iaculis. Pellentesque non commodo justo. Morbi feugiat rhoncus neque, vitae facilisis diam aliquam nec. Sed dapibus vitae quam at tristique. Nunc vel commodo mi. Mauris et rhoncus leo.
        `} />
        <Alert variant="warning" truncateTitle={2} title={`
Lorem ipsum dolor sit amet, consectetur adipiscing elit. Curabitur pellentesque neque cursus enim fringilla tincidunt. Proin lobortis aliquam dictum. Nam vel ullamcorper nulla, nec blandit dolor. Vivamus pellentesque neque justo, nec accumsan nulla rhoncus id. Suspendisse mollis, tortor quis faucibus volutpat, sem leo fringilla turpis, ac lacinia augue metus in nulla. Cras vestibulum lacinia orci. Pellentesque sodales consequat interdum. Sed porttitor tincidunt metus nec iaculis. Pellentesque non commodo justo. Morbi feugiat rhoncus neque, vitae facilisis diam aliquam nec. Sed dapibus vitae quam at tristique. Nunc vel commodo mi. Mauris et rhoncus leo.
        `} />
        <Alert variant="danger" truncateTitle={3} title={`
Lorem ipsum dolor sit amet, consectetur adipiscing elit. Curabitur pellentesque neque cursus enim fringilla tincidunt. Proin lobortis aliquam dictum. Nam vel ullamcorper nulla, nec blandit dolor. Vivamus pellentesque neque justo, nec accumsan nulla rhoncus id. Suspendisse mollis, tortor quis faucibus volutpat, sem leo fringilla turpis, ac lacinia augue metus in nulla. Cras vestibulum lacinia orci. Pellentesque sodales consequat interdum. Sed porttitor tincidunt metus nec iaculis. Pellentesque non commodo justo. Morbi feugiat rhoncus neque, vitae facilisis diam aliquam nec. Sed dapibus vitae quam at tristique. Nunc vel commodo mi. Mauris et rhoncus leo.
        `} />
      </React.Fragment>
    );
  }
}
```

### Custom icons
```js
import React from 'react';
import { Alert } from '@patternfly/react-core';
import UsersIcon from '@patternfly/react-icons/dist/js/icons/users-icon';
import BoxIcon from '@patternfly/react-icons/dist/js/icons/box-icon';
import DatabaseIcon from '@patternfly/react-icons/dist/js/icons/database-icon';
import ServerIcon from '@patternfly/react-icons/dist/js/icons/server-icon';
import LaptopIcon from '@patternfly/react-icons/dist/js/icons/laptop-icon';

class AlertTypes extends React.Component {
  render() {
    return (
      <React.Fragment>
        <Alert customIcon={<UsersIcon />} title="Default alert title" />
        <Alert customIcon={<BoxIcon />} variant="info" title="Info alert title" />
        <Alert customIcon={<DatabaseIcon />} variant="success" title="Success alert title" />
        <Alert customIcon={<ServerIcon />} variant="warning" title="Warning alert title" />
        <Alert customIcon={<LaptopIcon />} variant="danger" title="Danger alert title" />
      </React.Fragment>
    );
  }
}
```
